<?xml version="1.0" ?><!DOCTYPE TS><TS language="ast" version="2.1">
<context>
    <name>DAboutDialog</name>
    <message>
        <location filename="../src/widgets/daboutdialog.cpp" line="191"/>
        <source>Acknowledgements</source>
        <translation>Agradecimientos</translation>
    </message>
    <message>
        <location filename="../src/widgets/dapplication.cpp" line="712"/>
        <source>Version: %1</source>
        <translation>Versión; %1</translation>
    </message>
    <message>
        <location filename="../src/widgets/dapplication.cpp" line="716"/>
        <source>%1 is released under %2</source>
        <translation>%1 llánzase so %2</translation>
    </message>
</context>
<context>
    <name>DCrumbEdit</name>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="530"/>
        <source>Black</source>
        <translation>Prietu</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="533"/>
        <source>White</source>
        <translation>Blancu</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="536"/>
        <source>Dark Gray</source>
        <translation>Buxu escuru</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="539"/>
        <source>Gray</source>
        <translation>Buxu</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="542"/>
        <source>Light Gray</source>
        <translation>Buxu claru</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="545"/>
        <source>Red</source>
        <translation>Bermeyu</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="548"/>
        <source>Green</source>
        <translation>Verde</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="551"/>
        <source>Blue</source>
        <translation>Azul</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="554"/>
        <source>Cyan</source>
        <translation>Cian</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="557"/>
        <source>Magenta</source>
        <translation>Maxenta</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="560"/>
        <source>Yellow</source>
        <translation>Mariellu</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="563"/>
        <source>Dark Red</source>
        <translation>Bermeyu escuru</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="566"/>
        <source>Dark Green</source>
        <translation>Verde escuru</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="569"/>
        <source>Dark Blue</source>
        <translation>Azul escuru</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="572"/>
        <source>Dark Cyan</source>
        <translation>Cian escuru</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="575"/>
        <source>Dark Magenta</source>
        <translation>Maxenta escuru</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="578"/>
        <source>Dark Yellow</source>
        <translation>Mariellu escuru</translation>
    </message>
</context>
<context>
    <name>DInputDialog</name>
    <message>
        <location filename="../src/widgets/dinputdialog.cpp" line="42"/>
        <source>Cancel</source>
        <translation>Encaboxar</translation>
    </message>
    <message>
        <location filename="../src/widgets/dinputdialog.cpp" line="43"/>
        <source>Confirm</source>
        <translation>Confirmar</translation>
    </message>
</context>
<context>
    <name>DShortcutEdit</name>
    <message>
        <location filename="../src/widgets/dshortcutedit.cpp" line="31"/>
        <source>Please input a new shortcut</source>
        <translation>Introduz un atayu nuevu, por favor</translation>
    </message>
    <message>
        <location filename="../src/widgets/dshortcutedit.cpp" line="102"/>
        <source>None</source>
        <translation>Dengún</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/widgets/dsimplelistview.cpp" line="1235"/>
        <source>No search result</source>
        <translation>Nun hai dengún resultáu de gueta</translation>
    </message>
    <message>
        <location filename="../src/widgets/private/settings/content.cpp" line="189"/>
        <source>Restore Defaults</source>
        <translation>Reafitar valores</translation>
    </message>
</context>
<context>
    <name>ShortcutEdit</name>
    <message>
        <location filename="../src/widgets/private/settings/shortcutedit.cpp" line="119"/>
        <source>Please enter a new shortcut</source>
        <translation>Introduz un atayu nuevu, por favor</translation>
    </message>
</context>
<context>
    <name>TitleBarMenu</name>
    <message>
        <location filename="../src/widgets/dtitlebar.cpp" line="449"/>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
    <message>
        <location filename="../src/widgets/dtitlebar.cpp" line="456"/>
        <source>About</source>
        <translation>Tocante a</translation>
    </message>
    <message>
        <location filename="../src/widgets/dtitlebar.cpp" line="463"/>
        <source>Exit</source>
        <translation>Colar</translation>
    </message>
</context>
</TS>